import pygame
import random

from configmodel import Config

configs = [
    Config('4k', 1610, 1400),
    Config('fullhd', 805, 700)
]

pygame.init()
clock = pygame.time.Clock()

screen_width = 1610
screen_height = 1400

with open("../config.txt") as conf:
    conf = conf.read().split("\n")
    resolution = conf[0].split("=")[1].lower()

    for config in configs:
        if resolution == config.resolution_name:
            screen_width = config.screen_width
            screen_height = config.screen_height

k = 1610 / screen_width

play_height = 1198 / k
play_width = 1510 / k
player_width = 200 / k
player_height = 20 / k
ball_size = 30 / k
top_left_x = (screen_width - play_width) // 2
top_left_y = screen_height - play_height - 2

v_x = random.choice((-10, 10))
v_y = 10
v_player = 0

time = None

bricks = []

border = None
player = None
ball = None

score = 0
lives = 5


def init_objects():
    global border, player, ball
    border = pygame.Rect(top_left_x, top_left_y, play_width, play_height)
    player = pygame.Rect(screen_width / 2 - player_width / 2, screen_height - player_height - 20,
                         player_width, player_height)
    ball = pygame.Rect(player.center[0], player.top - ball_size,
                       ball_size, ball_size)


def init_bricks():
    global bricks
    for i in range(3):
        for j in range(6):
            bricks.append(pygame.Rect(j * (250 // k) + top_left_x + (10 // k), i * (50 // k) + top_left_y + (10 // k), 240 // k, 40 // k))


def draw_text_middle(text, size, color, surface, delta_x=0, delta_y=0, left=False):
    font = pygame.font.Font('../resources/fonts/font.ttf', size)
    label = font.render(text, True, color)
    if left:
        surface.blit(label, (screen_width / 2 + delta_x,
                             screen_height / 2 + delta_y))
    else:
        surface.blit(label, (screen_width / 2 - (label.get_width() / 2) + delta_x,
                            screen_height / 2 - label.get_height() * 2 + delta_y))


def draw_player():
    player.x += v_player
    if player.left <= border.left + 5:
        player.left = border.left + 5
    elif player.right >= border.right - 5:
        player.right = border.right - 5


def restart():
    global v_x, v_y, time, lives
    if lives <= 0:
        run = True
        while run:
            window.fill((0, 0, 0))
            draw_text_middle("You lost.", int(80 / k), (0, 255, 0), window, delta_y=-60 / k)
            draw_text_middle("Press <enter> to restart,", int(80 / k), (0, 255, 0), window, delta_y=120 / k)
            draw_text_middle("or <esc> to exit.", int(80 / k), (0, 255, 0), window, delta_y=180 / k)
            pygame.display.update()
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    run = False
                if event.type == pygame.KEYDOWN:
                    if event.key == pygame.K_RETURN:
                        main_menu()
                    elif event.key == pygame.K_ESCAPE:
                        run = False
                        quit()
        pygame.quit()
    else:
        ball.x, ball.y = player.center[0] - ball_size / 2, player.top - ball_size

        current_time = pygame.time.get_ticks()

        if current_time - time < 2100:
            v_x, v_y = 0, 0
        else:
            v_x, v_y = random.choice((-10, 10)), 10
            time = None


def draw_ball():
    global v_x, v_y, time, lives
    ball.x += v_x
    ball.y += v_y

    if ball.left <= border.left + 5:
        v_x *= -1
    elif ball.right >= border.right - 5:
        v_x *= -1
    elif ball.top <= border.top + 5:
        v_y *= -1
    if ball.colliderect(player):
        if abs(ball.right - player.left) < 15:
            v_x *= -1
        elif abs(ball.left - player.right) < 15:
            v_x *= -1
        elif abs(ball.bottom - player.top) < 15 and v_y > 0:
            v_y *= -1
        elif abs(ball.top - player.bottom) < 15 and v_y < 0:
            v_y *= -1

    if ball.bottom > border.bottom + 5:
        lives -= 1
        time = pygame.time.get_ticks()


def draw_bricks():
    global v_y, v_x, score
    if len(bricks) > 0:
        for el in bricks:
            pygame.draw.rect(window, (0, 255, 0), el, border_radius=2)

        for el in bricks:
            if ball.colliderect(el):
                score += 5
                if abs(ball.right - el.left) < 15:
                    v_x *= -1
                elif abs(ball.left - el.right) < 15:
                    v_x *= -1
                elif abs(ball.bottom - el.top) < 15 and v_y > 0:
                    v_y *= -1
                elif abs(ball.top - el.bottom) < 15 and v_y < 0:
                    v_y *= -1
                bricks.remove(el)
    else:
        run = True
        while run:
            window.fill((0, 0, 0))
            draw_text_middle("You won.", int(80 / k), (0, 255, 0), window, delta_y=-60 / k)
            draw_text_middle("Press <enter> to restart,", int(80 / k), (0, 255, 0), window, delta_y=120 / k)
            draw_text_middle("or <esc> to exit.", int(80 / k), (0, 255, 0), window, delta_y=180 / k)
            pygame.display.update()
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    run = False
                if event.type == pygame.KEYDOWN:
                    if event.key == pygame.K_RETURN:
                        main_menu()
                    elif event.key == pygame.K_ESCAPE:
                        run = False
                        quit()
        pygame.quit()


def main():
    init_objects()
    global v_player, v_y, v_x, lives
    init_bricks()
    paused = False
    running = True
    while running:
        window.fill((0, 0, 0))
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                running = False
                quit()
            elif event.type == pygame.KEYUP:
                if event.key == pygame.K_RIGHT:
                    v_player -= 10
                elif event.key == pygame.K_LEFT:
                    v_player += 10
            elif event.type == pygame.KEYDOWN:
                if event.key == pygame.K_RIGHT:
                    v_player += 10
                elif event.key == pygame.K_LEFT:
                    v_player -= 10
                if event.key == pygame.K_ESCAPE:
                    import __main__
                    __main__.main()
                if event.key == pygame.K_SPACE:
                    paused = not paused
        if not paused:
            draw_player()
            draw_ball()
            draw_bricks()
            if time:
                restart()

            pygame.draw.rect(window, (0, 255, 0), border, 5)
            pygame.draw.rect(window, (0, 255, 0), player, border_radius=5)
            pygame.draw.rect(window, (0, 255, 0), ball, border_radius=int(ball_size / 2))
            draw_text_middle("Arkanoid", int(100 / k), (0, 255, 0), window, delta_y=-450 / k)
            draw_text_middle(f"Score: {score}", int(100 / k), (0, 255, 0), window, delta_y=-450 / k,
                             delta_x= -screen_width / 3)
            draw_text_middle(f"Lives: {lives}", int(100 / k), (0, 255, 0), window, delta_y=-450 / k,
                             delta_x=screen_width / 3)
            pygame.display.update()
            clock.tick(int(60 / k))
        else:
            window.fill((0, 0, 0))
            draw_text_middle('Paused', int(120 / k), (0, 255, 0), window)
            pygame.display.update()
            paused = check_pause(paused)
            continue
    pygame.quit()


def check_pause(paused):
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            pygame.display.quit()
            quit()
        if event.type == pygame.KEYDOWN:
            if event.key == pygame.K_SPACE:
                paused = not paused
    return paused


def main_menu():
    run = True
    while run:
        window.fill((0, 0, 0))

        draw_text_middle('Press any key to begin.', int(120 / k), (0, 255, 0), window)
        pygame.display.update()
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                run = False

            if event.type == pygame.KEYDOWN:
                main()
    pygame.quit()


window = pygame.display.set_mode((screen_width, screen_height))
pygame.display.set_caption('Arkanoid')

main_menu()



import pygame
import random

from oldreality.configmodel.configmodel import Config

configs = [
    Config('4k', 1600, 1400),
    Config('fullhd', 800, 700)
]

# Инициализация pygame
pygame.init()
clock = pygame.time.Clock()

# Глобальные переменные
screen_width = 1600
screen_height = 1400

with open("../config.txt") as conf:
    conf = conf.read().split("\n")
    resolution = conf[0].split("=")[1].lower()
    for config in configs:
        if resolution == config.resolution_name:
            screen_width = config.screen_width
            screen_height = config.screen_height

k = 1600 / screen_width

ball_size = 30 / k
play_height = 1198 / k
play_width = 1500 / k
top_left_x = (screen_width - play_width) // 2
top_left_y = screen_height - play_height - 2

platform_height = 140 / k
platform_width = 10 / k

# Рисование основных элементов окна
ball = pygame.Rect(play_width / 2 - ball_size / 2, play_height / 2 - ball_size / 2,
                   ball_size, ball_size)
opponent = pygame.Rect(play_width + 20 / k, play_height / 2 + 20 / k + top_left_x, platform_width, platform_height)
player = pygame.Rect(20 / k + top_left_x, play_height / 2 + 20 / k + top_left_x, platform_width, platform_height)
border = pygame.Rect(top_left_x, top_left_y, play_width, play_height)

# Переменные цвета
bg_color = (0, 0, 0)
green = (0, 255, 0)

# Переменные скорости
v_x = 10
v_y = 10
v_player = 0
v_opponent = 7

# Время
time = True


# Счет
player_score = 0
opponent_score = 0

# Звук
bounce = pygame.mixer.Sound("../resources/sounds/pong.ogg")
win = pygame.mixer.Sound("../resources/sounds/score.ogg")


def ai():
    if ball.x > screen_width / 2:
        if opponent.top < ball.y:
            opponent.top += v_opponent
        elif opponent.bottom > ball.y:
            opponent.bottom -= v_opponent
        if opponent.top <= top_left_y:
            opponent.top = top_left_y
        elif opponent.bottom >= screen_height:
            opponent.bottom = screen_height


def restart():
    global v_x, v_y, time

    ball.center = (play_width / 2 + top_left_x, play_height / 2 + top_left_y)
    current_time = pygame.time.get_ticks()

    if current_time - time < 700:
        draw_text_middle("3", int(100 / k), (0, 255, 0), window, delta_x=100 / k, delta_y=150 / k)
        v_x, v_y = 0, 0
    elif current_time - time < 1400:
        draw_text_middle("2", int(100 / k), (0, 255, 0), window, delta_x=100 / k, delta_y=150 / k)
        v_x, v_y = 0, 0
    elif current_time - time < 2100:
        draw_text_middle("1", int(100 / k), (0, 255, 0), window, delta_x=100 / k, delta_y=150 / k)
        v_x, v_y = 0, 0
    else:
        v_x, v_y = random.choice((-10, 10)), 10
        time = None


def draw_ball():
    global v_x, v_y, time, opponent_score, player_score
    ball.x += v_x
    ball.y += v_y

    if ball.top <= top_left_y + 5 or ball.bottom >= play_height + top_left_y:
        v_y *= -1
        pygame.mixer.Sound.play(bounce)
    if ball.left <= top_left_x:
        opponent_score += 1
        time = pygame.time.get_ticks()
        pygame.mixer.Sound.play(win)
    elif ball.right > top_left_x + play_width:
        player_score += 1
        time = pygame.time.get_ticks()
        pygame.mixer.Sound.play(win)
    if ball.colliderect(opponent) and v_x > 0:
        pygame.mixer.Sound.play(bounce)
        v_x *= -1
    if ball.colliderect(player) and v_x < 0:
        pygame.mixer.Sound.play(bounce)
        v_x *= -1


def draw_player():
    player.y += v_player
    if player.top <= top_left_y:
        player.top = top_left_y
    if player.bottom >= screen_height:
        player.bottom = screen_height


def draw_text_middle(text, size, color, surface, delta_x=0, delta_y=0):
    font = pygame.font.Font('../resources/fonts/font.ttf', size)
    label = font.render(text, True, color)

    surface.blit(label, (top_left_x + play_width / 2 - (label.get_width() / 2) + delta_x,
                         top_left_y + play_height / 2 - label.get_height() * 2 + delta_y))


def main():
    global v_player
    running = True
    paused = False
    while running:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                running = False
                pygame.quit()
                quit()
            elif event.type == pygame.KEYDOWN:
                if event.key == pygame.K_DOWN:
                    v_player += 10
                elif event.key == pygame.K_UP:
                    v_player -= 10
                if event.key == pygame.K_SPACE:
                    paused = not paused

                if event.key == pygame.K_ESCAPE:
                    import __main__
                    __main__.main()
            elif event.type == pygame.KEYUP:
                if event.key == pygame.K_DOWN:
                    v_player -= 10
                elif event.key == pygame.K_UP:
                    v_player += 10
        if not paused:
            draw_ball()
            draw_player()
            ai()

            window.fill(bg_color)
            pygame.draw.rect(window, green, player)
            pygame.draw.rect(window, green, opponent)
            pygame.draw.aaline(window, green, (screen_width / 2, top_left_y), (screen_width / 2, screen_height))
            pygame.draw.rect(window, green, ball)
            pygame.draw.rect(window, green, border, 5)
        else:
            window.fill((0, 0, 0))
            draw_text_middle('Paused', int(60 / k), (0, 255, 0), window)
            pygame.display.update()
            paused = check_pause(paused)
            continue

        if time:
            restart()

        draw_text_middle("Pong", int(100 / k), (0, 255, 0), window, delta_y=-550 / k)
        draw_text_middle(f"{player_score}:{opponent_score}", int(50 / k), (0, 255, 0), window, delta_y=-550 / k)
        pygame.display.flip()
        clock.tick(int(60 / k))


def check_pause(paused):
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            pygame.display.quit()
            quit()
        if event.type == pygame.KEYDOWN:
            if event.key == pygame.K_SPACE:
                paused = not paused
    return paused


def main_menu():
    run = True
    while run:
        window.fill((0, 0, 0))

        draw_text_middle('Press any key to begin.', int(120 / k), (0, 255, 0), window)
        pygame.display.update()
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                run = False

            if event.type == pygame.KEYDOWN:
                main()
    pygame.quit()


# Объявление окна
window = pygame.display.set_mode((screen_width, screen_height))
pygame.display.set_caption('Pong')

main_menu() # Запуск игры



import pygame
import random

from oldreality.configmodel.configmodel import Config

configs = [
    Config('4k', 1600, 1400),
    Config('fullhd', 800, 700)
]
pygame.font.init()

# Глобальные переменные
fps = 30

screen_width = 800
screen_height = 700

try:
    with open("../config.txt") as conf:
        conf = conf.read().split("\n")
        resolution = conf[0].split("=")[1].lower()
        for config in configs:
            if resolution == config.resolution_name:
                screen_width = config.screen_width
                screen_height = config.screen_height
except Exception as e:
    print(e)


k = 1600 / screen_width

play_width = 600 / k
play_height = 1200 / k
block_size = 60 / k

top_left_x = (screen_width - play_width) // 2
top_left_y = screen_height - play_height

# Фигурки

S = [['.....',
      '.....',
      '..00.',
      '.00..',
      '.....'],
     ['.....',
      '..0..',
      '..00.',
      '...0.',
      '.....']]

Z = [['.....',
      '.....',
      '.00..',
      '..00.',
      '.....'],
     ['.....',
      '..0..',
      '.00..',
      '.0...',
      '.....']]

I = [['..0..',
      '..0..',
      '..0..',
      '..0..',
      '.....'],
     ['.....',
      '0000.',
      '.....',
      '.....',
      '.....']]

O = [['.....',
      '.....',
      '.00..',
      '.00..',
      '.....']]

J = [['.....',
      '.0...',
      '.000.',
      '.....',
      '.....'],
     ['.....',
      '..00.',
      '..0..',
      '..0..',
      '.....'],
     ['.....',
      '.....',
      '.000.',
      '...0.',
      '.....'],
     ['.....',
      '..0..',
      '..0..',
      '.00..',
      '.....']]

L = [['.....',
      '...0.',
      '.000.',
      '.....',
      '.....'],
     ['.....',
      '..0..',
      '..0..',
      '..00.',
      '.....'],
     ['.....',
      '.....',
      '.000.',
      '.0...',
      '.....'],
     ['.....',
      '.00..',
      '..0..',
      '..0..',
      '.....']]

T = [['.....',
      '..0..',
      '.000.',
      '.....',
      '.....'],
     ['.....',
      '..0..',
      '..00.',
      '..0..',
      '.....'],
     ['.....',
      '.....',
      '.000.',
      '..0..',
      '.....'],
     ['.....',
      '..0..',
      '.00..',
      '..0..',
      '.....']]

shapes = [S, Z, I, O, J, L, T]
shape_colors = [(0, 255, 0), (255, 0, 0), (0, 255, 255), (255, 255, 0), (255, 165, 0), (0, 0, 255), (128, 0, 128)]


class Piece(object):
    rows = 20  # y
    columns = 10  # x

    def __init__(self, column, row, shape):
        self.x = column
        self.y = row
        self.shape = shape
        self.color = shape_colors[shapes.index(shape)]
        self.rotation = 0  # Число 0-3


def create_grid(locked_positions={}):
    grid = [[(0, 0, 0) for _ in range(10)] for _ in range(20)]

    for i in range(len(grid)):
        for j in range(len(grid[i])):
            if (j, i) in locked_positions:
                c = locked_positions[(j, i)]
                grid[i][j] = c
    return grid


def convert_shape_format(shape):
    positions = []
    format = shape.shape[shape.rotation % len(shape.shape)]

    for i, line in enumerate(format):
        row = list(line)
        for j, column in enumerate(row):
            if column == '0':
                positions.append((shape.x + j, shape.y + i))

    for i, pos in enumerate(positions):
        positions[i] = (pos[0] - 2, pos[1] - 4)

    return positions


def valid_space(shape, grid):
    accepted_positions = [[(j, i) for j in range(10) if grid[i][j] == (0, 0, 0)] for i in range(20)]
    accepted_positions = [j for sub in accepted_positions for j in sub]
    formatted = convert_shape_format(shape)

    for pos in formatted:
        if pos not in accepted_positions:
            if pos[1] > -1:
                return False

    return True


def check_lost(positions):
    for pos in positions:
        x, y = pos
        if y < 1:
            return True
    return False


def get_shape():
    global shapes, shape_colors

    return Piece(5, 0, random.choice(shapes))


def draw_text_middle(text, size, color, surface, delta_x=0, delta_y=0):
    font = pygame.font.Font('../resources/fonts/font.ttf', size)
    label = font.render(text, True, color)

    surface.blit(label, (top_left_x + play_width / 2 - (label.get_width() / 2) + delta_x,
                         top_left_y + play_height / 2 - label.get_height() * 2 + delta_y))


def draw_grid(surface, row, col):
    sx = top_left_x
    sy = top_left_y
    for i in range(row):
        pygame.draw.line(surface, (128, 128, 128), (sx, sy + i * block_size),
                         (sx + play_width, sy + i * block_size))  # Горизонтальные линии
        for j in range(col):
            pygame.draw.line(surface, (128, 128, 128), (sx + j * block_size, sy),
                             (sx + j * block_size, sy + play_height))  # Вертикальные линии


def clear_rows(grid, locked):
    inc = 0
    for i in range(len(grid) - 1, -1, -1):
        row = grid[i]
        if (0, 0, 0) not in row:
            inc += 1
            ind = i
            for j in range(len(row)):
                try:
                    del locked[(j, i)]
                except:
                    continue
    if inc > 0:
        for key in sorted(list(locked), key=lambda x: x[1])[::-1]:
            x, y = key
            if y < ind:
                newKey = (x, y + inc)
                locked[newKey] = locked.pop(key)


def draw_next_shape(shape, surface):
    font = pygame.font.Font('../resources/fonts/font.ttf', int(60 / k))
    label = font.render('Next Shape', True, (0, 255, 0))

    sx = top_left_x + play_width + 50
    sy = top_left_y + play_height / 2 - 100
    format = shape.shape[shape.rotation % len(shape.shape)]

    for i, line in enumerate(format):
        row = list(line)
        for j, column in enumerate(row):
            if column == '0':
                pygame.draw.rect(surface, shape.color, (sx + j * block_size, sy + i * block_size,
                                                        block_size, block_size))
                pygame.draw.rect(surface, (128, 128, 128), (sx + j * block_size, sy + i * block_size,
                                                            block_size, block_size), 1)

    surface.blit(label, (sx + 20 / k, sy - block_size))


def draw_window(surface):
    surface.fill((0, 0, 0))
    # Tetris Title
    font = pygame.font.Font('../resources/fonts/font.ttf', int(120 / k))
    label = font.render('TETRIS', True, (0, 255, 0))

    surface.blit(label, (top_left_x + play_width / 2 - (label.get_width() / 2), block_size))

    for i in range(len(grid)):
        for j in range(len(grid[i])):
            pygame.draw.rect(surface, grid[i][j], (top_left_x + j * block_size, top_left_y + i * block_size,
                                                   block_size, block_size), 0)

    # Рисуем клетки и границы
    draw_grid(surface, 20, 10)
    pygame.draw.rect(surface, (0, 255, 0), (top_left_x, top_left_y, play_width, play_height), 5)


def main():
    global grid

    locked_positions = {}  # (x,y):(255,0,0)
    grid = create_grid(locked_positions)

    change_piece = False
    run = True
    current_piece = get_shape()
    next_piece = get_shape()
    clock = pygame.time.Clock()
    fall_time = 0
    paused = False

    key_left_pressed_time = 0
    key_right_pressed_time = 0
    pressed_time_for_move = 12

    fall_speed = 0.07

    while run:
        if not paused:
            grid = create_grid(locked_positions)
            fall_time += clock.get_rawtime()
            clock.tick(fps)

            # PIECE FALLING CODE
            if fall_time / 1000 >= fall_speed:
                fall_time = 0
                current_piece.y += 1
                if not (valid_space(current_piece, grid)) and current_piece.y > 0:
                    current_piece.y -= 1
                    change_piece = True
        else:
            window.fill((0, 0, 0))
            draw_text_middle('Paused', int(120 / k), (0, 255, 0), window)
            pygame.display.update()
            paused = check_pause(paused)
            continue

        def moveShapeLeft():
            current_piece.x -= 1
            if not valid_space(current_piece, grid):
                current_piece.x += 1

        def moveShapeRight():
            current_piece.x += 1
            if not valid_space(current_piece, grid):
                current_piece.x -= 1

        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                run = False
                pygame.display.quit()
                quit()

            if event.type == pygame.KEYDOWN:
                # if event.key == pygame.K_LEFT:
                #     current_piece.x -= 1
                #     if not valid_space(current_piece, grid):
                #         current_piece.x += 1

                # if event.key == pygame.K_RIGHT:
                #     current_piece.x += 1
                #     if not valid_space(current_piece, grid):
                #         current_piece.x -= 1
                if event.key == pygame.K_LEFT:
                    moveShapeLeft()
                elif event.key == pygame.K_RIGHT:
                    moveShapeRight()

                elif event.key == pygame.K_UP:
                    # rotate shape
                    current_piece.rotation = current_piece.rotation + 1 % len(current_piece.shape)
                    if not valid_space(current_piece, grid):
                        current_piece.rotation = current_piece.rotation - 1 % len(current_piece.shape)

                if event.key == pygame.K_SPACE:
                    paused = not paused

                if event.key == pygame.K_ESCAPE:
                    import __main__
                    __main__.main()
            if event.type == pygame.KEYUP:
                if event.key == pygame.K_LEFT:
                    key_left_pressed_time = 0
                elif event.key == pygame.K_RIGHT:
                    key_right_pressed_time = 0

        keys = pygame.key.get_pressed()
        if keys[pygame.K_DOWN]:
            current_piece.y += 1
            if not valid_space(current_piece, grid):
                current_piece.y -= 1
        elif keys[pygame.K_LEFT]:
            key_left_pressed_time += 1
            if key_left_pressed_time >= pressed_time_for_move:
                moveShapeLeft()
        elif keys[pygame.K_RIGHT]:
            key_right_pressed_time += 1
            if key_right_pressed_time >= pressed_time_for_move:
                moveShapeRight()

        shape_pos = convert_shape_format(current_piece)

        # add piece to the grid for drawing
        for i in range(len(shape_pos)):
            x, y = shape_pos[i]
            if y > -1:
                grid[y][x] = current_piece.color

        # IF PIECE HIT GROUND
        if change_piece:
            for pos in shape_pos:
                p = (pos[0], pos[1])
                locked_positions[p] = current_piece.color
            current_piece = next_piece
            next_piece = get_shape()
            change_piece = False

            # call four times to check for multiple clear rows
            clear_rows(grid, locked_positions)

            fall_speed -= 0.0005

        draw_window(window)
        draw_next_shape(next_piece, window)
        pygame.display.update()

        # Check if user lost
        if check_lost(locked_positions):
            run = False

    window.fill((0, 0, 0))
    draw_text_middle("You Lost.", int(80 / k), (0, 255, 0), window, delta_y=-30)
    draw_text_middle("Press enter to restart,", int(80 / k), (0, 255, 0), window, delta_y=60)
    draw_text_middle("or esc to exit.", int(80 / k), (0, 255, 0), window, delta_y=90)
    pygame.display.update()
    run = True
    while run:
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                run = False
                pygame.display.quit()
                quit()

            if event.type == pygame.KEYDOWN:
                if event.key == pygame.K_ESCAPE:
                    run = False
                    pygame.display.quit()
                    quit()
                elif event.key == pygame.K_RETURN:
                    run = False
                    main_menu()



def check_pause(paused):
    for event in pygame.event.get():
        if event.type == pygame.QUIT:
            pygame.display.quit()
            quit()
        if event.type == pygame.KEYDOWN:
            if event.key == pygame.K_SPACE:
                paused = not paused
    return paused


def main_menu():
    run = True
    while run:
        window.fill((0, 0, 0))

        draw_text_middle('Press any key to begin.', int(120 / k), (0, 255, 0), window)
        pygame.display.update()
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                run = False

            if event.type == pygame.KEYDOWN:
                main()
    pygame.quit()


window = pygame.display.set_mode((screen_width, screen_height))
pygame.display.set_caption('Tetris')

main_menu()  # Запуск игры



class Config:
    def __init__(self,
                 resolution_name: str,
                 screen_width: int,
                 screen_height: int):
        self.resolution_name = resolution_name.lower()
        self.screen_width = screen_width
        self.screen_height = screen_height



import pygame
import importlib
import sys
import os
import json

from oldreality.configmodel.configmodel import Config


configs = [
    Config('4k', 1600, 1400),
    Config('fullhd', 800, 700)
]

pygame.init()
clock = pygame.time.Clock()

screen_width = 1600
screen_height = 1400

with open("config.txt") as conf:
    conf = conf.read().split("\n")
    resolution = conf[0].split("=")[1].lower()

    for config in configs:
        if resolution == config.resolution_name:
            screen_width = config.screen_width
            screen_height = config.screen_height


with open("resources/langs/tetris_en.json") as lang:
    data = json.load(lang)
    print(data)



k = 1600 / screen_width



games_list = ["tetris", "pong", "arkanoid"]
image_list = []

x_coord = 0


def load_image(name, colorkey=None):
    fullname = f"resources/images/{name}"
    # если файл не существует, то выходим
    if not os.path.isfile(fullname):
        print(f"Файл с изображением '{fullname}' не найден")
        sys.exit()
    image = pygame.image.load(fullname)
    return image


for el in games_list:
    image_list.append(load_image(el + ".png"))


def draw_text_middle(text, size, color, surface, delta_x=0, delta_y=0, left=False):
    size = size - 5 * (1 if int(k) == 2 else 2)
    font = pygame.font.Font('resources/fonts/font.ttf', size)
    label = font.render(text, True, color)
    if left:
        surface.blit(label, (screen_width / 2 + delta_x,
                             screen_height / 2 + delta_y))
    else:
        surface.blit(label, (screen_width / 2 - (label.get_width() / 2) + delta_x,
                            screen_height / 2 - label.get_height() * 2 + delta_y))


def update_cursor():
    draw_text_middle(">", int(100 / k), (0, 255, 0), window, delta_x=int(300 / k),
                     delta_y=x_coord * 100 / k - (15 if int(k) == 1 else 10))
    window.blit(pygame.transform.scale(image_list[x_coord], (int(800 / k), int(800 / k))), (200 / k, 400 / k))
    border = pygame.Rect(200 / k, 400 / k, 800 / k, 800 / k)
    pygame.draw.rect(window, (0, 255, 0), border, 5)


def draw_list():
    for i, el in enumerate(games_list):
        draw_text_middle(el, int(100 / k), (0, 255, 0), window, delta_x=400 / k,
                         delta_y=i * 100 / k - 200 / k, left=True)


def main():
    global x_coord
    running = True
    while running:
        window.fill((0, 0, 0))
        draw_text_middle("OldReality", int(160 / k), (0, 255, 0), window, delta_y=-300 / k)
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                running = False
                quit()
            elif event.type == pygame.KEYDOWN:
                if event.key == pygame.K_DOWN:
                    if x_coord < len(games_list) - 1:
                        x_coord += 1
                    else:
                        x_coord = 0

                elif event.key == pygame.K_UP:
                    if x_coord > 0:
                        x_coord -= 1
                    else:
                        x_coord = len(games_list) - 1
                elif event.key == pygame.K_RETURN:
                    game = importlib.import_module(games_list[x_coord])
                    game.main_menu()
        update_cursor()
        draw_list()
        pygame.display.update()
    pygame.quit()


window = pygame.display.set_mode((screen_width, screen_height))
pygame.display.set_caption('Main game menu')

main()
